@@ -93,7 +93,7 @@ class Stock:
     def __init__(self, ticker,  target_prices=None, price_invested=None):
         # interval='1m', period='1d',
         try:
-            self.ticker = ticker.upper()
+            self.ticker = ticker
             self.df = Ticker(ticker).get_data()
             self.prev_close = self.df.iloc[-1]
             self.target_prices = target_prices
